@@ -255,6 +255,9 @@
 #define LLDP_CAP_TELEPHONE 0x20
 #define LLDP_CAP_DOCSIS 0x40
 #define LLDP_CAP_STATION 0x80
+#define LLDP_CAP_CVLAN 0x100
+#define LLDP_CAP_SVLAN 0x200
+#define LLDP_CAP_TPMRCOMP 0x400
 
 #define LLDP_PPVID_CAP_SUPPORTED (1 << 1)
 #define LLDP_PPVID_CAP_ENABLED (1 << 2)
